@@ -284,7 +284,7 @@ class Sylo:
                 f";"
             )
             if with_id is False:
-                display.print_incomplete_tasks(self.tasks)
+                display.print_tasks(self.tasks)
             else:
                 display.print_tasks_with_id(self.tasks)
             logger.info(f"Tasks: {self.tasks}")
