@@ -1,11 +1,11 @@
 import sys
 import logging
-from sylo.definitions import ROOT_DIR
+from sylo.definitions import SYLO_HOME
 
 logger = logging.getLogger(__name__)
 
 
-LOG_FILE_NAME = f"{ROOT_DIR}/../sylo.log"
+LOG_FILE_NAME = f"{SYLO_HOME}/sylo.log"
 LOG_FILE_FORMAT = "%(asctime)s %(module)s %(levelname)s: %(message)s"
 DEFAULT_LOG_LEVEL = logging.WARN
 
